==> mca_projen_jsii_example-1.4.0-py3-none-any.whl: mca_projen_jsii_example/__init__.py <==
'''
# MCA Projen JSii Example

[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/marciocadev/mca-projen-jsii-example)
[![NPM version](https://img.shields.io/npm/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/js/mca-projen-jsii-example)
[![PyPI version](https://img.shields.io/pypi/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/py/mca-projen-jsii-example)
[![NuGet version](https://img.shields.io/nuget/v/Projen.Jsii?label=nuget%20package&color=brightgreen)](https://badge.fury.io/nu/Projen.Jsii)
[![Maven Central](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example.svg?label=maven%20central&color=brightgreen)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Reference](https://pkg.go.dev/badge/github.com/marciocadev/mca-projen-jsii-example-go.svg)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go)
[![release](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml/badge.svg)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml)

<!-- Test  --><!-- [![Maven](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example?label=version&color=brightgreen&logo=java)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Version](https://img.shields.io/badge/dynamic/json?color=brightgreen&query=%24.Version&url=https%3A%2F%2Fproxy.golang.org%2Fgithub.com%2Fmarciocadev%2Fmca-projen-jsii-example%2F%40v%2Fv1.1.7.info&logo=go&label=version)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/marciocadev/mca-projen-jsii-example/release?logo=github&label=release)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml) --><!--
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example)

[![Go Reference](https://pkg.go.dev/badge/github.com/projen/projen-go.svg)](https://pkg.go.dev/github.com/projen/projen-go/projen) --><!-- [![npm version](https://badge.fury.io/js/mca-projen-jsii-example.svg)](https://badge.fury.io/js/mca-projen-jsii-example) --><!-- [![PyPI version](https://badge.fury.io/py/mca-projen-jsii-example.svg)](https://badge.fury.io/py/mca-projen-jsii-example) --><!-- [![NuGet version](https://badge.fury.io/nu/Projen.Jsii.svg)](https://badge.fury.io/nu/Projen.Jsii) -->

The **MCA Projen JSii Example** it's a test project to learn how deploy at NPM, PyPi and Maven repositories, auto-versioning and runing git actions on commits
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *


class Hello(metaclass=jsii.JSIIMeta, jsii_type="mca-projen-jsii-example.Hello"):
    '''My Hello class.'''

    def __init__(self) -> None:
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="sayHello")
    def say_hello(self, name: builtins.str) -> builtins.str:
        '''My sayHello function.

        :param name: Someone who calls.

        :return: Greetings
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "sayHello", [name]))


__all__ = [
    "Hello",
]

publication.publish()

==> mca_projen_jsii_example-1.10.0-py3-none-any.whl: mca_projen_jsii_example/__init__.py <==
'''
# MCA Projen JSii Example

[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/marciocadev/mca-projen-jsii-example)
[![codecov](https://codecov.io/gh/marciocadev/mca-projen-jsii-example/branch/main/graph/badge.svg?token=U1R3MKJWJO)](https://codecov.io/gh/marciocadev/mca-projen-jsii-example)
[![NPM version](https://img.shields.io/npm/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/js/mca-projen-jsii-example)
[![PyPI version](https://img.shields.io/pypi/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/py/mca-projen-jsii-example)
[![NuGet version](https://img.shields.io/nuget/v/Projen.Jsii?label=nuget%20package&color=brightgreen)](https://badge.fury.io/nu/Projen.Jsii)
[![Maven Central](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example.svg?label=maven%20central&color=brightgreen)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Reference](https://pkg.go.dev/badge/github.com/marciocadev/mca-projen-jsii-example-go/mcaprojenjsiiexample.svg)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go/mcaprojenjsiiexample)
[![release](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml/badge.svg)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml)

<!-- Test  --><!-- [![Maven](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example?label=version&color=brightgreen&logo=java)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Version](https://img.shields.io/badge/dynamic/json?color=brightgreen&query=%24.Version&url=https%3A%2F%2Fproxy.golang.org%2Fgithub.com%2Fmarciocadev%2Fmca-projen-jsii-example%2F%40v%2Fv1.1.7.info&logo=go&label=version)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/marciocadev/mca-projen-jsii-example/release?logo=github&label=release)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml) --><!--
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example)

[![Go Reference](https://pkg.go.dev/badge/github.com/projen/projen-go.svg)](https://pkg.go.dev/github.com/projen/projen-go/projen) --><!-- [![npm version](https://badge.fury.io/js/mca-projen-jsii-example.svg)](https://badge.fury.io/js/mca-projen-jsii-example) --><!-- [![PyPI version](https://badge.fury.io/py/mca-projen-jsii-example.svg)](https://badge.fury.io/py/mca-projen-jsii-example) --><!-- [![NuGet version](https://badge.fury.io/nu/Projen.Jsii.svg)](https://badge.fury.io/nu/Projen.Jsii) -->

The **MCA Projen JSii Example** it's a test project to learn how deploy at NPM, PyPi and Maven repositories, auto-versioning and runing git actions on commits
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *


class Hello(metaclass=jsii.JSIIMeta, jsii_type="mca-projen-jsii-example.Hello"):
    '''My Hello class.'''

    def __init__(self) -> None:
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="sayGodbye")
    def say_godbye(self, name: builtins.str) -> builtins.str:
        '''My sayGodbye function.

        :param name: Someone who calls.

        :return: Godbye
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "sayGodbye", [name]))

    @jsii.member(jsii_name="sayHello")
    def say_hello(self, name: builtins.str) -> builtins.str:
        '''My sayHello function.

        :param name: Someone who calls.

        :return: Greetings
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "sayHello", [name]))


__all__ = [
    "Hello",
]

publication.publish()
